@@ -2,19 +2,19 @@
  * Programmer(s): Allan Taylor, Alan Hindmarsh and
  *                Radu Serban @ LLNL
  * -----------------------------------------------------------------
- * LLNS Copyright Start
- * Copyright (c) 2017, Lawrence Livermore National Security
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Lawrence Livermore National Laboratory in part under 
- * Contract W-7405-Eng-48 and in part under Contract DE-AC52-07NA27344.
- * Produced at the Lawrence Livermore National Laboratory.
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  * -----------------------------------------------------------------
  * Example program for IDA: Food web problem.
  *
- * This example program (serial version) uses the banded linear 
+ * This example program (serial version) uses the banded linear
  * solver, and IDACalcIC for initial condition calculation.
  *
  * The mathematical problem solved in this example is a DAE system
@@ -125,15 +125,15 @@
 #define NOUT        6              /* Number of output times            */
 #define TMULT       RCONST(10.0)   /* Multiplier for tout values        */
 #define TADD        RCONST(0.3)    /* Increment for tout values         */
-#define ZERO        RCONST(0.)     
-#define ONE         RCONST(1.0)    
+#define ZERO        RCONST(0.)
+#define ONE         RCONST(1.0)
 
-/* 
+/*
  * User-defined vector and accessor macro: IJ_Vptr.
- * IJ_Vptr is defined in order to express the underlying 3-D structure of 
+ * IJ_Vptr is defined in order to express the underlying 3-D structure of
  * the dependent variable vector from its underlying 1-D storage (an N_Vector).
- * IJ_Vptr(vv,i,j) returns a pointer to the location in vv corresponding to 
- * species index is = 0, x-index ix = i, and y-index jy = j.                
+ * IJ_Vptr(vv,i,j) returns a pointer to the location in vv corresponding to
+ * species index is = 0, x-index ix = i, and y-index jy = j.
  */
 
 #define IJ_Vptr(vv,i,j) (&NV_Ith_S(vv, (i)*NUM_SPECIES + (j)*NSMX))
@@ -149,7 +149,7 @@ typedef struct {
 
 /* Prototypes for functions called by the IDA Solver. */
 
-static int resweb(realtype time, N_Vector cc, N_Vector cp, N_Vector resval, 
+static int resweb(realtype time, N_Vector cc, N_Vector cp, N_Vector resval,
                   void *user_data);
 
 /* Prototypes for private Helper Functions. */
@@ -161,7 +161,7 @@ static void PrintHeader(sunindextype mu, sunindextype ml, realtype rtol, realtyp
 static void PrintOutput(void *mem, N_Vector c, realtype t);
 static void PrintFinalStats(void *mem);
 static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate, UserData webdata);
-static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy, 
+static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
                      UserData webdata);
 static realtype dotprod(sunindextype size, realtype *x1, realtype *x2);
 static int check_retval(void *returnvalue, const char *funcname, int opt);
@@ -173,7 +173,7 @@ static int check_retval(void *returnvalue, const char *funcname, int opt);
  */
 
 int main()
-{ 
+{
   void *mem;
   UserData webdata;
   N_Vector cc, cp, id;
@@ -207,17 +207,17 @@ int main()
 
   id  = N_VNew_Serial(NEQ);
   if(check_retval((void *)id, "N_VNew_Serial", 0)) return(1);
-  
+
   SetInitialProfiles(cc, cp, id, webdata);
-  
+
   /* Set remaining inputs to IDAMalloc. */
-  
+
   t0 = ZERO;
-  rtol = RTOL; 
+  rtol = RTOL;
   atol = ATOL;
 
   /* Call IDACreate and IDAMalloc to initialize IDA. */
-  
+
   mem = IDACreate();
   if(check_retval((void *)mem, "IDACreate", 0)) return(1);
 
@@ -251,27 +251,27 @@ int main()
   tout = RCONST(0.001);
   retval = IDACalcIC(mem, IDA_YA_YDP_INIT, tout);
   if(check_retval(&retval, "IDACalcIC", 1)) return(1);
-  
+
   /* Print heading, basic parameters, and initial values. */
 
   PrintHeader(mu, ml, rtol, atol);
   PrintOutput(mem, cc, ZERO);
-  
+
   /* Loop over iout, call IDASolve (normal mode), print selected output. */
-  
+
   for (iout = 1; iout <= NOUT; iout++) {
-    
+
     retval = IDASolve(mem, tout, &tret, cc, cp, IDA_NORMAL);
     if(check_retval(&retval, "IDASolve", 1)) return(retval);
-    
+
     PrintOutput(mem, cc, tret);
-    
+
     if (iout < 3) tout *= TMULT; else tout += TADD;
-    
+
   }
-  
-  /* Print final statistics and free memory. */  
-  
+
+  /* Print final statistics and free memory. */
+
   PrintFinalStats(mem);
 
   /* Free memory */
@@ -292,7 +292,7 @@ int main()
   return(0);
 }
 
-/* Define lines for readability in later routines */ 
+/* Define lines for readability in later routines */
 
 #define acoef  (webdata->acoef)
 #define bcoef  (webdata->bcoef)
@@ -305,32 +305,32 @@ int main()
  *--------------------------------------------------------------------
  */
 
-/* 
+/*
  * resweb: System residual function for predator-prey system.
  * This routine calls Fweb to get all the right-hand sides of the
  * equations, then loads the residual vector accordingly,
- * using cp in the case of prey species.                 
+ * using cp in the case of prey species.
  */
 
-static int resweb(realtype tt, N_Vector cc, N_Vector cp, 
+static int resweb(realtype tt, N_Vector cc, N_Vector cp,
                   N_Vector res,  void *user_data)
 {
   sunindextype jx, jy, is, yloc, loc, np;
   realtype *resv, *cpv;
   UserData webdata;
-  
+
   webdata = (UserData)user_data;
-  
+
   cpv = N_VGetArrayPointer(cp);
   resv = N_VGetArrayPointer(res);
   np = webdata->np;
-  
+
   /* Call Fweb to set res to vector of right-hand sides. */
   Fweb(tt, cc, res, webdata);
-  
+
   /* Loop over all grid points, setting residual values appropriately
      for differential or algebraic components.                        */
-  
+
   for (jy = 0; jy < MY; jy++) {
     yloc = NSMX * jy;
     for (jx = 0; jx < MX; jx++) {
@@ -343,9 +343,9 @@ static int resweb(realtype tt, N_Vector cc, N_Vector cp,
       }
     }
   }
-  
+
   return(0);
-  
+
 }
 
 /*
@@ -355,12 +355,12 @@ static int resweb(realtype tt, N_Vector cc, N_Vector cp,
  */
 
 /*
- * InitUserData: Load problem constants in webdata (of type UserData).   
+ * InitUserData: Load problem constants in webdata (of type UserData).
  */
 
 static void InitUserData(UserData webdata)
 {
-  int i, j, np;
+  sunindextype i, j, np;
   realtype *a1,*a2, *a3, *a4, dx2, dy2;
 
   webdata->mx = MX;
@@ -370,11 +370,11 @@ static void InitUserData(UserData webdata)
   webdata->dx = AX/(MX-1);
   webdata->dy = AY/(MY-1);
   webdata->Neq= NEQ;
-  
+
   /* Set up the coefficients a and b, and others found in the equations. */
   np = webdata->np;
   dx2 = (webdata->dx)*(webdata->dx); dy2 = (webdata->dy)*(webdata->dy);
-  
+
   for (i = 0; i < np; i++) {
     a1 = &(acoef[i][np]);
     a2 = &(acoef[i+np][0]);
@@ -387,25 +387,25 @@ static void InitUserData(UserData webdata)
       *a3++ = ZERO;
       *a4++ = ZERO;
     }
-    
+
     /* Reset the diagonal elements of acoef to -AA. */
     acoef[i][i] = -AA; acoef[i+np][i+np] = -AA;
-    
+
     /* Set coefficients for b and diffusion terms. */
     bcoef[i] = BB; bcoef[i+np] = -BB;
     cox[i] = DPREY/dx2; cox[i+np] = DPRED/dx2;
     coy[i] = DPREY/dy2; coy[i+np] = DPRED/dy2;
   }
-  
+
 }
 
-/* 
+/*
  * SetInitialProfiles: Set initial conditions in cc, cp, and id.
  * A polynomial profile is used for the prey cc values, and a constant
  * (1.0e5) is loaded as the initial guess for the predator cc values.
  * The id values are set to 1 for the prey and 0 for the predators.
  * The prey cp values are set according to the given system, and
- * the predator cp values are set to zero.                               
+ * the predator cp values are set to zero.
  */
 
 static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
@@ -414,12 +414,12 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
   sunindextype loc, yloc, is, jx, jy, np;
   realtype xx, yy, xyfactor;
   realtype *ccv, *cpv, *idv;
-  
+
   ccv = N_VGetArrayPointer(cc);
   cpv = N_VGetArrayPointer(cp);
   idv = N_VGetArrayPointer(id);
   np = webdata->np;
-  
+
   /* Loop over grid, load cc values and id values. */
   for (jy = 0; jy < MY; jy++) {
     yy = jy * webdata->dy;
@@ -442,10 +442,10 @@ static void SetInitialProfiles(N_Vector cc, N_Vector cp, N_Vector id,
       }
     }
   }
-  
+
   /* Set c' for the prey by calling the function Fweb. */
   Fweb(ZERO, cc, cp, webdata);
-  
+
   /* Set c' for predators to 0. */
   for (jy = 0; jy < MY; jy++) {
     yloc = NSMX * jy;
@@ -468,9 +468,9 @@ static void PrintHeader(sunindextype mu, sunindextype ml, realtype rtol, realtyp
   printf("Number of species ns: %d", NUM_SPECIES);
   printf("     Mesh dimensions: %d x %d", MX, MY);
   printf("     System size: %d\n", NEQ);
-#if defined(SUNDIALS_EXTENDED_PRECISION) 
+#if defined(SUNDIALS_EXTENDED_PRECISION)
   printf("Tolerance parameters:  rtol = %Lg   atol = %Lg\n", rtol, atol);
-#elif defined(SUNDIALS_DOUBLE_PRECISION) 
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
 #else
   printf("Tolerance parameters:  rtol = %g   atol = %g\n", rtol, atol);
@@ -481,13 +481,13 @@ static void PrintHeader(sunindextype mu, sunindextype ml, realtype rtol, realtyp
   printf("  t        bottom-left  top-right");
   printf("    | nst  k      h\n");
   printf("-----------------------------------------------------------\n\n");
-  
+
 }
 
-/* 
+/*
  * PrintOutput: Print output values at output time t = tt.
  * Selected run statistics are printed.  Then values of the concentrations
- * are printed for the bottom left and top right grid points only.  
+ * are printed for the bottom left and top right grid points only.
  */
 
 static void PrintOutput(void *mem, N_Vector c, realtype t)
@@ -502,22 +502,22 @@ static void PrintOutput(void *mem, N_Vector c, realtype t)
   check_retval(&retval, "IDAGetNumSteps", 1);
   retval = IDAGetLastStep(mem, &hused);
   check_retval(&retval, "IDAGetLastStep", 1);
-  
+
   c_bl = IJ_Vptr(c,0,0);
   c_tr = IJ_Vptr(c,MX-1,MY-1);
 
-#if defined(SUNDIALS_EXTENDED_PRECISION) 
-  printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n", 
+#if defined(SUNDIALS_EXTENDED_PRECISION)
+  printf("%8.2Le %12.4Le %12.4Le   | %3ld  %1d %12.4Le\n",
          t, c_bl[0], c_tr[0], nst, kused, hused);
   for (i=1;i<NUM_SPECIES;i++)
     printf("         %12.4Le %12.4Le   |\n",c_bl[i],c_tr[i]);
-#elif defined(SUNDIALS_DOUBLE_PRECISION) 
-  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
+#elif defined(SUNDIALS_DOUBLE_PRECISION)
+  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n",
          t, c_bl[0], c_tr[0], nst, kused, hused);
   for (i=1;i<NUM_SPECIES;i++)
     printf("         %12.4e %12.4e   |\n",c_bl[i],c_tr[i]);
 #else
-  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n", 
+  printf("%8.2e %12.4e %12.4e   | %3ld  %1d %12.4e\n",
          t, c_bl[0], c_tr[0], nst, kused, hused);
   for (i=1;i<NUM_SPECIES;i++)
     printf("         %12.4e %12.4e   |\n",c_bl[i],c_tr[i]);
@@ -526,12 +526,12 @@ static void PrintOutput(void *mem, N_Vector c, realtype t)
   printf("\n");
 }
 
-/* 
- * PrintFinalStats: Print final run data contained in iopt.              
+/*
+ * PrintFinalStats: Print final run data contained in iopt.
  */
 
 static void PrintFinalStats(void *mem)
-{ 
+{
   long int nst, nre, nreLS, nni, nje, netf, ncfn;
   int retval;
 
@@ -561,27 +561,27 @@ static void PrintFinalStats(void *mem)
 
 }
 
-/* 
- * Fweb: Rate function for the food-web problem.                        
- * This routine computes the right-hand sides of the system equations,   
- * consisting of the diffusion term and interaction term.                
- * The interaction term is computed by the function WebRates.            
+/*
+ * Fweb: Rate function for the food-web problem.
+ * This routine computes the right-hand sides of the system equations,
+ * consisting of the diffusion term and interaction term.
+ * The interaction term is computed by the function WebRates.
  */
 
-static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,  
+static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,
                  UserData webdata)
-{ 
+{
   sunindextype jx, jy, is, idyu, idyl, idxu, idxl;
   realtype xx, yy, *cxy, *ratesxy, *cratexy, dcyli, dcyui, dcxli, dcxui;
-  
+
   /* Loop over grid points, evaluate interaction vector (length ns),
      form diffusion difference terms, and load crate.                    */
-  
+
   for (jy = 0; jy < MY; jy++) {
     yy = (webdata->dy) * jy ;
     idyu = (jy!=MY-1) ? NSMX : -NSMX;
     idyl = (jy!= 0  ) ? NSMX : -NSMX;
-    
+
     for (jx = 0; jx < MX; jx++) {
       xx = (webdata->dx) * jx;
       idxu = (jx!= MX-1) ?  NUM_SPECIES : -NUM_SPECIES;
@@ -589,32 +589,32 @@ static void Fweb(realtype tcalc, N_Vector cc, N_Vector crate,
       cxy = IJ_Vptr(cc,jx,jy);
       ratesxy = IJ_Vptr(webdata->rates,jx,jy);
       cratexy = IJ_Vptr(crate,jx,jy);
-      
+
       /* Get interaction vector at this grid point. */
       WebRates(xx, yy, cxy, ratesxy, webdata);
-      
+
       /* Loop over species, do differencing, load crate segment. */
       for (is = 0; is < NUM_SPECIES; is++) {
-        
+
         /* Differencing in y. */
         dcyli = *(cxy+is) - *(cxy - idyl + is) ;
         dcyui = *(cxy + idyu + is) - *(cxy+is);
-        
+
         /* Differencing in x. */
         dcxli = *(cxy+is) - *(cxy - idxl + is);
         dcxui = *(cxy + idxu +is) - *(cxy+is);
-        
+
         /* Compute the crate values at (xx,yy). */
         cratexy[is] = coy[is] * (dcyui - dcyli) +
           cox[is] * (dcxui - dcxli) + ratesxy[is];
-        
+
       } /* End is loop */
     } /* End of jx loop */
   } /* End of jy loop */
-  
+
 }
 
-/* 
+/*
  * WebRates: Evaluate reaction rates at a given spatial point.
  * At a given (x,y), evaluate the array of ns reaction terms R.
  */
@@ -624,30 +624,30 @@ static void WebRates(realtype xx, realtype yy, realtype *cxy, realtype *ratesxy,
 {
   int is;
   realtype fac;
-  
+
   for (is = 0; is < NUM_SPECIES; is++)
     ratesxy[is] = dotprod(NUM_SPECIES, cxy, acoef[is]);
-  
+
   fac = ONE + ALPHA*xx*yy + BETA*sin(FOURPI*xx)*sin(FOURPI*yy);
-  
-  for (is = 0; is < NUM_SPECIES; is++)  
+
+  for (is = 0; is < NUM_SPECIES; is++)
     ratesxy[is] = cxy[is]*( bcoef[is]*fac + ratesxy[is] );
-  
+
 }
 
 /*
- * dotprod: dot product routine for realtype arrays, for use by WebRates.    
+ * dotprod: dot product routine for realtype arrays, for use by WebRates.
  */
 
 static realtype dotprod(sunindextype size, realtype *x1, realtype *x2)
 {
   sunindextype i;
   realtype *xx1, *xx2, temp = ZERO;
-  
+
   xx1 = x1; xx2 = x2;
   for (i = 0; i < size; i++) temp += (*xx1++) * (*xx2++);
   return(temp);
-  
+
 }
 
 /*
@@ -657,7 +657,7 @@ static realtype dotprod(sunindextype size, realtype *x1, realtype *x2)
  *   opt == 1 means SUNDIALS function returns an integer value so check if
  *            retval < 0
  *   opt == 2 means function allocates memory so check if returned
- *            NULL pointer 
+ *            NULL pointer
  */
 
 static int check_retval(void *returnvalue, const char *funcname, int opt)
@@ -666,25 +666,25 @@ static int check_retval(void *returnvalue, const char *funcname, int opt)
 
   if (opt == 0 && returnvalue == NULL) {
     /* Check if SUNDIALS function returned NULL pointer - no memory allocated */
-    fprintf(stderr, 
-            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n", 
+    fprintf(stderr,
+            "\nSUNDIALS_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
     return(1);
   } else if (opt == 1) {
     /* Check if retval < 0 */
     retval = (int *) returnvalue;
     if (*retval < 0) {
-      fprintf(stderr, 
-              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n", 
+      fprintf(stderr,
+              "\nSUNDIALS_ERROR: %s() failed with retval = %d\n\n",
               funcname, *retval);
-      return(1); 
+      return(1);
     }
   } else if (opt == 2 && returnvalue == NULL) {
     /* Check if function returned NULL pointer - no memory allocated */
-    fprintf(stderr, 
-            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n", 
+    fprintf(stderr,
+            "\nMEMORY_ERROR: %s() failed - returned NULL pointer\n\n",
             funcname);
-    return(1); 
+    return(1);
   }
 
   return(0);
