@@ -1,15 +1,15 @@
 /* ----------------------------------------------------------------- 
  * Programmer(s): Radu Serban and Cosmin Petra @ LLNL
  * -----------------------------------------------------------------
- * LLNS Copyright Start
- * Copyright (c) 2014, Lawrence Livermore National Security
- * This work was performed under the auspices of the U.S. Department 
- * of Energy by Lawrence Livermore National Laboratory in part under 
- * Contract W-7405-Eng-48 and in part under Contract DE-AC52-07NA27344.
- * Produced at the Lawrence Livermore National Laboratory.
+ * SUNDIALS Copyright Start
+ * Copyright (c) 2002-2019, Lawrence Livermore National Security
+ * and Southern Methodist University.
  * All rights reserved.
- * For details, see the LICENSE file.
- * LLNS Copyright End
+ *
+ * See the top-level LICENSE and NOTICE files for details.
+ *
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SUNDIALS Copyright End
  * -----------------------------------------------------------------
  *
  * Hessian using adjoint sensitivity example problem. 
@@ -124,7 +124,7 @@ int main(int argc, char *argv[])
   void *ida_mem;
   UserData data;
   realtype time, ti, tf;
-  int retval, nckp, indexB1, indexB2;
+  int retval, nckp, indexB1, indexB2, is;
   realtype G, Gm, Gp, dp1, dp2, grdG_fwd[2], grdG_bck[2], grdG_cntr[2], H11, H22;
   realtype rtolFD, atolFD;
   SUNMatrix A, AB1, AB2;
@@ -159,7 +159,7 @@ int main(int argc, char *argv[])
   N_VConst(ZERO, ypS[0]); N_VConst(ZERO, ypS[1]);
 
   qS = N_VCloneVectorArray(NP, q);
-  N_VConst(ZERO, qS[0]);
+  for(is=0; is<NP; is++) N_VConst(ZERO, qS[is]);
 
   ida_mem = IDACreate();
 
